#!/usr/bin/env python
# -*- coding: utf-8 -*-
from builtins import str
from pynamodb.exceptions import GetError

from db_paribhasha import credentials as creds
from db_paribhasha.dynamo import dynamo_constants as db_cnts
from db_paribhasha.dynamo import dynamo_helpers as db_hlpr
from db_paribhasha.dynamo.metadata import MetadataDynamoDB
from db_paribhasha.error_handler import DynamoDBError


def create_table():
    """
    Creates PreLoginDynamoDB table if table doesn't exist
    """
    if MetadataDynamoDB.exists():
        raise DynamoDBError(db_cnts.TABLE_EXISTS.format(
                            creds.DYNAMO_METADATA_TABLE))
    MetadataDynamoDB.create_table(
        read_capacity_units=creds.DYNAMO_PRELOGIN_READ_UNITS,
        write_capacity_units=creds.DYNAMO_PRELOGIN_WRITE_UNITS)


def get_metadata(page_url):
    """
    Returns the data based on page URL

    Parameters
    ----------
    page_url : str
        Page URL

    Returns
    -------
    data: dict
        Metadata fetched on the basis of page_url
    """
    try:
        data = MetadataDynamoDB.get(page_url)
    except GetError as err:
        raise DynamoDBError(str(err))
    return data.to_dict()


def save_metadata(page_url, data):
    """
    Saves the data based on a given page_url

    Parameters
    ----------
    page_url : str
        Page URL
    data: dict
        Metadata for a given page_url

    Returns
    -------
    bool: True if object gets saved in dynamodb
    """
    create_metadata = MetadataDynamoDB(page_url=page_url, data=data)
    db_hlpr.save_dynamo_object(create_metadata)
    return True
